%% create_std_text
%   function will create an edit text box used for conditons and
%   results. we want these to be consistent so its easier for it to
%   be in one function.
% inputs:
%   obj:GUI - current GUI object
%   Parent:double - handle to parent figure
%   position:[double double double double] - position to place edit
%       box in.
% outputs:
%   control:double - handle pointing to newly created uicontrol
% Author: Colin Eles elesc@mcmaster.ca
% Organization: McMaster Centre for Software Certification
function control = create_std_text(object, Parent, position)
control = uicontrol('style','edit',...
    'Parent',Parent,...
    'units','pix',...
    'position',position,...
    'min',0,'max',1,...  % This is the key to multiline edits.
    'string',{''},...
    'Max',2.0,...
    'fontweight','bold',...
    'BackgroundColor',[1 1 1],...
    'horizontalalign','center',...
    'KeyPressFcn',@(src,event)textbox_callback(object,src,event),...
    'fontsize',11);
end

